All platforms.

bigjule.modifiers.check


count-overclj/s

(count-over rolls arguments)

This returns the number of dice rolled equal to or above the first supplied argument in the dice specification.

This returns the number of dice rolled equal to or above the first
supplied argument in the dice specification.
sourceraw docstring

count-underclj/s

(count-under rolls arguments)

This returns the number of dice rolled equal to or under the first supplied argument in the dice specification.

This returns the number of dice rolled equal to or under the first
supplied argument in the dice specification.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries