(discard-highest rolls arguments)Modifier fn that discards the highest roll from the total. This effectively reduces the dices count by 1, but biases the total towards lower results.
Modifier fn that discards the highest roll from the total. This effectively reduces the dices count by 1, but biases the total towards lower results.
(discard-lowest rolls arguments)Modifier fn that discards the lowest roll from the total. This effectively reduces the dice count by 1, but biases the total towards a higher result.
Modifier fn that discards the lowest roll from the total. This effectively reduces the dice count by 1, but biases the total towards a higher result.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |