(count-over rolls arguments)This returns the number of dice rolled equal to or above the first supplied argument in the dice specification.
This returns the number of dice rolled equal to or above the first supplied argument in the dice specification.
(count-under rolls arguments)This returns the number of dice rolled equal to or under the first supplied argument in the dice specification.
This returns the number of dice rolled equal to or under the first supplied argument in the dice specification.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |